Method: ComputeUnit::AmdGpu.devices

Defined in:
lib/compute_unit/gpus/amd_gpu.rb

.devicesArray

Returns - returns a list of device paths of all devices specific to the vendor id.

Returns:

  • (Array)
    • returns a list of device paths of all devices specific to the vendor id



74
75
76
# File 'lib/compute_unit/gpus/amd_gpu.rb', line 74

def self.devices
  ComputeUnit::Gpu.devices.find_all { |f| device_vendor(f) == VENDOR_ID }
end