Method: ComputeUnit::AmdGpu#rom_metadata

Defined in:
lib/compute_unit/gpus/amd_gpu.rb

#rom_metadataArray

Returns - an array of readable strings from the rom file.

Returns:

  • (Array)
    • an array of readable strings from the rom file



55
56
57
58
59
60
# File 'lib/compute_unit/gpus/amd_gpu.rb', line 55

def 
   || begin
    printable_chars = %r{[A-Za-z0-9`~!@#%^&*()-_=+|'";:/?.>,< \t\$\{\}\[\]\\]{10,}}
    read_rom_data.scan(printable_chars)[0..9]
  end
end