Method: ComputeUnit::Device.name_translation

Defined in:
lib/compute_unit/device.rb

.name_translation(name) ⇒ String

Returns - translation of vendor names to how we known them.

Returns:

  • (String)
    • translation of vendor names to how we known them



205
206
207
# File 'lib/compute_unit/device.rb', line 205

def self.name_translation(name)
  name_map[name] || name
end