Method: ComputeUnit::Device.subsystem_vendor_lookup

Defined in:
lib/compute_unit/device.rb

.subsystem_vendor_lookup(vendor_id) ⇒ String

Returns - the name of the subsystem vendor with a possible translation.

Returns:

  • (String)
    • the name of the subsystem vendor with a possible translation



348
349
350
351
# File 'lib/compute_unit/device.rb', line 348

def self.subsystem_vendor_lookup(vendor_id)
  # "1002  Advanced Micro Devices, Inc. [AMD/ATI]\n"
  vendor_lookup(vendor_id)
end