Method: ComputeUnit::Device.system_checksum

Defined in:
lib/compute_unit/device.rb

.system_checksumString

Returns - a sha1 digest that represents the pci devices found on the system.

Returns:

  • (String)
    • a sha1 digest that represents the pci devices found on the system



298
299
300
301
302
# File 'lib/compute_unit/device.rb', line 298

def self.system_checksum
  @system_checksum ||= Dir.chdir(ComputeUnit::SYS_DEVICE_PATH) do
    Digest::SHA1.hexdigest(Dir.glob('*').sort.join)
  end
end