Method: ComputeUnit::Device#hwmon_path

Defined in:
lib/compute_unit/device.rb

#hwmon_pathString

Note:

this path can be different for each device

Note:

returns the base_hwmon_path if no path is found

Returns - the directory path to the hwmon dir for this device.

Returns:

  • (String)
    • the directory path to the hwmon dir for this device



166
167
168
169
170
171
# File 'lib/compute_unit/device.rb', line 166

def hwmon_path
  @hwmon_path ||= begin
    paths = Dir.glob(File.join(base_hwmon_path, '*'))
    paths.first || base_hwmon_path
  end
end