Method: ComputeUnit::Device#make

Defined in:
lib/compute_unit/device.rb,
lib/compute_unit/device.rb

#makeString (readonly)

Returns - the name of the vendor who made the device.

Returns:

  • (String)
    • the name of the vendor who made the device



87
88
89
# File 'lib/compute_unit/device.rb', line 87

def make
  @make
end