Method: ComputeUnit::Device#vendor

Defined in:
lib/compute_unit/device.rb,
lib/compute_unit/device.rb

#vendorString (readonly)

Returns - the name of the vendor who resold the device.

Returns:

  • (String)
    • the name of the vendor who resold the device



95
96
97
# File 'lib/compute_unit/device.rb', line 95

def vendor
  @vendor
end