Method: ComputeUnit::Device#write_kernel_setting

Defined in:
lib/compute_unit/device.rb

#write_kernel_setting(setting, value) ⇒ String

Returns - a reading of the kernel setting using the device_path.

Parameters:

  • value (String)
    • the value to assign to the setting

  • setting (String)
    • the name of the kernel file in the device path to read

Returns:

  • (String)
    • a reading of the kernel setting using the device_path



82
83
84
# File 'lib/compute_unit/device.rb', line 82

def write_kernel_setting(setting, value)
  self.class.write_kernel_setting(device_path, setting, value)
end