Method: ComputeUnit::AmdGpu#power_average
- Defined in:
- lib/compute_unit/gpus/amd_gpu.rb
#power_average ⇒ Float
Returns the average power being used by the gpu.
190 191 192 193 |
# File 'lib/compute_unit/gpus/amd_gpu.rb', line 190 def power_average # TODO: if a gpu crashes the average power can sometimes take 3000 ms to read! read_hwmon_data('power1_average', 0).to_i / 1000000 end |